@@ -333,6 +333,7 @@ from bitmovin_api_sdk.models.he_aac_v2_signaling import HeAacV2Signaling
 from bitmovin_api_sdk.models.hls_manifest import HlsManifest
 from bitmovin_api_sdk.models.hls_manifest_default import HlsManifestDefault
 from bitmovin_api_sdk.models.hls_manifest_default_version import HlsManifestDefaultVersion
+from bitmovin_api_sdk.models.hls_target_duration_rounding_mode import HlsTargetDurationRoundingMode
 from bitmovin_api_sdk.models.hls_version import HlsVersion
 from bitmovin_api_sdk.models.http_input import HttpInput
 from bitmovin_api_sdk.models.https_input import HttpsInput
@@ -518,6 +519,7 @@ from bitmovin_api_sdk.models.scc_caption import SccCaption
 from bitmovin_api_sdk.models.scheduled_insertable_content import ScheduledInsertableContent
 from bitmovin_api_sdk.models.scheduled_insertable_content_status import ScheduledInsertableContentStatus
 from bitmovin_api_sdk.models.scheduling import Scheduling
+from bitmovin_api_sdk.models.scte35_cue import Scte35Cue
 from bitmovin_api_sdk.models.segmented_raw_muxing import SegmentedRawMuxing
 from bitmovin_api_sdk.models.segments_media_info import SegmentsMediaInfo
 from bitmovin_api_sdk.models.sftp_input import SftpInput
